@@ -3,16 +3,16 @@
  * Copyright (C) 2006  Emmanuele Bassi <ebassi@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  *
@@ -32,7 +32,6 @@
 
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
-#include <gtk/gtkbindings.h>
 #include <glib/gi18n.h>
 
 #include "gdict-sidebar.h"
@@ -72,16 +71,10 @@ enum
 };
 
 static guint sidebar_signals[LAST_SIGNAL] = { 0 };
+static GQuark sidebar_page_id_quark = 0;
 
 G_DEFINE_TYPE (GdictSidebar, gdict_sidebar, GTK_TYPE_VBOX);
 
-#define SIDEBAR_PAGE_ID		(sidebar_page_id_quark ())
-static GQuark
-sidebar_page_id_quark (void)
-{
-  return g_quark_from_static_string ("gdict-sidebar-page-id");
-}
-
 SidebarPage *
 sidebar_page_new (const gchar *id,
 		  const gchar *name,
@@ -131,7 +124,7 @@ gdict_sidebar_finalize (GObject *object)
 }
 
 static void
-gdict_sidebar_destroy (GtkObject *object)
+gdict_sidebar_dispose (GObject *object)
 {
   GdictSidebar *sidebar = GDICT_SIDEBAR (object);
 
@@ -141,7 +134,7 @@ gdict_sidebar_destroy (GtkObject *object)
       sidebar->priv->menu = NULL;
     }
 
-  GTK_OBJECT_CLASS (gdict_sidebar_parent_class)->destroy (object);
+  G_OBJECT_CLASS (gdict_sidebar_parent_class)->dispose (object);
 }
 
 static void
@@ -261,7 +254,7 @@ gdict_sidebar_menu_item_activate (GtkWidget *widget,
   gint current_index;
 
   menu_item = gtk_menu_get_active (GTK_MENU (priv->menu));
-  id = g_object_get_qdata (G_OBJECT (menu_item), SIDEBAR_PAGE_ID);
+  id = g_object_get_qdata (G_OBJECT (menu_item), sidebar_page_id_quark);
   g_assert (id != NULL);
   
   page = g_hash_table_lookup (priv->pages_by_id, id);
@@ -282,10 +275,13 @@ static void
 gdict_sidebar_class_init (GdictSidebarClass *klass)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
-  GtkObjectClass *gtkobject_class = GTK_OBJECT_CLASS (klass);
+
+  g_type_class_add_private (gobject_class, sizeof (GdictSidebarPrivate));
+  
+  sidebar_page_id_quark = g_quark_from_static_string ("gdict-sidebar-page-id");
 
   gobject_class->finalize = gdict_sidebar_finalize;
-  gtkobject_class->destroy = gdict_sidebar_destroy;
+  gobject_class->dispose = gdict_sidebar_dispose;
 
   sidebar_signals[PAGE_CHANGED] =
     g_signal_new ("page-changed",
@@ -303,8 +299,6 @@ gdict_sidebar_class_init (GdictSidebarClass *klass)
 		  NULL, NULL,
 		  g_cclosure_marshal_VOID__VOID,
 		  G_TYPE_NONE, 0);
-
-  g_type_class_add_private (gobject_class, sizeof (GdictSidebarPrivate));
 }
 
 static void
@@ -438,8 +432,8 @@ gdict_sidebar_add_page (GdictSidebar *sidebar,
   /* add the menu item for the page */
   menu_item = gtk_image_menu_item_new_with_label (page_name);
   g_object_set_qdata_full (G_OBJECT (menu_item),
-		           SIDEBAR_PAGE_ID,
-			   g_strdup (page_id),
+			   sidebar_page_id_quark,
+                           g_strdup (page_id),
 			   (GDestroyNotify) g_free);
   g_signal_connect (menu_item, "activate",
 		    G_CALLBACK (gdict_sidebar_menu_item_activate),
@@ -522,8 +516,7 @@ gdict_sidebar_view_page (GdictSidebar *sidebar,
   if (!page)
     return;
 
-  gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook),
-		  		 page->index);
+  gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook), page->index);
   gtk_label_set_text (GTK_LABEL (priv->label), page->name);
   gtk_menu_shell_select_item (GTK_MENU_SHELL (priv->menu), page->menu_item);
 }
@@ -545,3 +538,28 @@ gdict_sidebar_current_page (GdictSidebar *sidebar)
 
   return page->id;
 }
+
+gchar **
+gdict_sidebar_list_pages (GdictSidebar *sidebar,
+                          gsize        *length)
+{
+  GdictSidebarPrivate *priv;
+  gchar **retval;
+  gint i;
+  GSList *l;
+
+  g_return_val_if_fail (GDICT_IS_SIDEBAR (sidebar), NULL);
+
+  priv = sidebar->priv;
+
+  retval = g_new (gchar*, g_slist_length (priv->pages) + 1);
+  for (l = priv->pages, i = 0; l; l = l->next, i++)
+    retval[i++] = g_strdup (l->data);
+
+  retval[i] = NULL;
+
+  if (length)
+    *length = i;
+
+  return retval;
+}
